@@ -22,7 +22,7 @@ my $ECDSA_CURVE = 'secp384r1';
 sub do_example {
     my ($handle_combination_cr) = @_;
 
-    my $tos_url = Net::ACME::LetsEncrypt->get_terms_of_service();
+    my $tos_url = Net::ACME::LetsEncrypt->get_terms_of_service() or die 'can’t get LE terms of service!';
     print "Look at:$/$/\t$tos_url$/$/… and hit CTRL-C if you DON’T accept these terms.$/";
     <STDIN>;
 
@@ -77,9 +77,9 @@ sub do_example {
                     last if $poll->status() eq 'valid';
 
                     if ( $poll->status() eq 'invalid' ) {
-                        my @failed = map { $_->error() } $poll->challenges();
+                        my @failed = map { $_->error() || () } $poll->challenges();
 
-                        print $_->to_string() . $/ for @failed;
+                        print( $_->to_string() . $/ ) for @failed;
 
                         die "Failed authorization for “$domain”!$/";
                     }
