@@ -11,9 +11,11 @@ use Net::ACME::Constants ();
 
 use Net_ACME_Example ();
 
+use Carp::Always;
+
 Net_ACME_Example::do_example(
     sub {
-        my ( $domain, $cmb_ar, $reg ) = @_;
+        my ( $domain, $cmb_ar, $key_jwk ) = @_;
 
         return if @$cmb_ar > 1;
 
@@ -22,7 +24,7 @@ Net_ACME_Example::do_example(
         return if $c->type() ne 'http-01';
 
         my $token            = $c->token();
-        my $key_authz        = $c->make_key_authz( $reg->key() );
+        my $key_authz        = $c->make_key_authz( $key_jwk );
         my $uri_to_be_loaded = "http://$domain/$Net::ACME::Constants::HTTP_01_CHALLENGE_DCV_DIR_IN_DOCROOT/$token";
 
         print "Now make it so that:$/$/\t$uri_to_be_loaded$/$/… contains this content:$/$/\t$key_authz$/";
