@@ -33,7 +33,7 @@ use parent qw( Net::ACME::AccessorBase );
 
 use constant _ACCESSORS => qw( error status );
 
-use Net::ACME::EvalBug ();
+use Net::ACME::Utils ();
 use Net::ACME::X ();
 
 my $ERROR_CLASS;
@@ -45,9 +45,7 @@ BEGIN {
 sub new {
     my ( $class, %opts ) = @_;
 
-    local $@ if !Net::ACME::EvalBug::bug_exists();
-
-    if ( $opts{'error'} && !eval { $opts{'error'}->isa($ERROR_CLASS) } ) {
+    if ( $opts{'error'} && !Net::ACME::Utils::thing_isa($opts{'error'}, $ERROR_CLASS) ) {
         die Net::ACME::X::create( 'InvalidParameter', "“error” must be an instance of “$ERROR_CLASS”, not “$opts{'error'}”!" );
     }
 
